package FBP::ToolSeparator;

use Mouse;

our $VERSION = '0.34';

extends 'FBP::Object';

no Mouse;
__PACKAGE__->meta->make_immutable;

1;
